@@ -4,7 +4,7 @@ class Prompt(object):
         return value
 
     def apply_default(self, value):
-        if len(value) == 0 and self.input.default is not None:
+        if len(str(value)) == 0 and self.input.default is not None:
             return self.input.default
 
         return value
